@@ -3,10 +3,10 @@ import json
 from b_aws_testing_framework.credentials import Credentials
 from botocore.response import StreamingBody
 
-from b_lambda_layer_common_test.integration.infrastructure import Infrastructure
+from b_lambda_layer_common_test.integration.infrastructure.main_stack import MainStack
 
 
-def test_RESOURCE_lambda_layer_WITH_deployed_lambda_function_EXPECT_execution_successful():
+def test_RESOURCE_lambda_layer_WITH_deployed_lambda_function_1_EXPECT_execution_successful():
     """
     Test whether the layer provides necessary functionality.
 
@@ -17,7 +17,7 @@ def test_RESOURCE_lambda_layer_WITH_deployed_lambda_function_EXPECT_execution_su
 
     # Invoke specific lambda function.
     response = lambda_client.invoke(
-        FunctionName=Infrastructure.get_output(Infrastructure.LAMBDA_FUNCTION_NAME_KEY),
+        FunctionName=MainStack.get_output(MainStack.LAMBDA_FUNCTION_1_NAME_KEY),
         InvocationType='RequestResponse'
     )
 
